package Bundle::Text::MagicTemplate;
$VERSION = 3.51;
__END__

=head1 NAME

Bundle::Text::MagicTemplate - A bundle to install MagicTemplate distribution plus all related extensions and prerequisites.

=head1 SYNOPSIS

    perl -MCPAN -e 'install Bundle::Text::MagicTemplate'

=head1 CONTENTS

HTML::Tagset            - used by HTML::Parser

HTML::Parser            - used by HTML::FillInForm and HTML::TableTiler

HTML::TableTiler        - used by HTML::MagicTemplate

HTML::FillInForm        - used by HTML::MagicTemplate

Class::constr           - used by Text::MagicTemplate::Zone

Class::props            - used by Text::MagicTemplate::Zone

Object::props           - used by Text::MagicTemplate::Zone

Template::Magic         - the main distribution

Text::MagicTemplate     - the old main distribution

=head1 DESCRIPTION

Obsolete Bundle: use Bundle::Template::Magic instead.

=head1 AUTHOR and COPYRIGHT

 2004 by Domizio Demichelis.

All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as perl itself.
